==> fullts-0.1.2.tgz: package/src/FullTsRouteRender.js <==
"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import * as React from 'react';
var FullTsRouteRender = /** @class */ (function (_super) {
    __extends(FullTsRouteRender, _super);
    function FullTsRouteRender(props, context) {
        var _this = _super.call(this, props, context) || this;
        _this.state = {};
        return _this;
    }
    FullTsRouteRender.prototype.componentWillMount = function () {
        var _this = this;
        if (this.props.route.render) {
            var result = this.props.route.render({
                match: this.props.match,
                location: this.props.location,
                history: this.props.history
            });
            if (result && result.then) {
                //is Promise
                result.then(function (v) {
                    _this.setState({
                        node: v
                    });
                });
            }
            else {
                //not Promise
                this.setState({
                    node: result
                });
            }
        }
        else if (this.props.route.component) {
            if (typeof this.props.route.component == 'function') {
                //function
                var result = this.props.route.component();
                if (result.then) {
                    result.then(function (v) {
                        _this.setState({
                            componentClass: v.default
                        });
                    });
                }
                else {
                    //pure component function
                    this.setState({
                        componentClass: this.props.route.component
                    });
                }
            }
            else {
                //not function
                this.setState({
                    componentClass: this.props.route.component
                });
            }
        }
    };
    FullTsRouteRender.prototype.render = function () {
        if (this.state.node) {
            //render
            return this.state.node;
        }
        else if (this.state.componentClass) {
            //component
            return React.createElement(this.state.componentClass, __assign({}, this.props.routeProps));
        }
        else {
            //loading
            return null;
        }
    };
    //<Switch></Switch>的BUG 如果不指定这个则会全部变成exact false
    FullTsRouteRender.defaultProps = {
        exact: true
    };
    return FullTsRouteRender;
}(React.Component));
export default FullTsRouteRender;

==> fullts-0.2.2.tgz: package/src/FullTsRouteRender.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import * as React from 'react';
var FullTsRouteRender = /** @class */ (function (_super) {
    __extends(FullTsRouteRender, _super);
    function FullTsRouteRender(props, context) {
        var _this = _super.call(this, props, context) || this;
        _this.state = {};
        return _this;
    }
    FullTsRouteRender.prototype.componentWillMount = function () {
        var _this = this;
        // if (this.props.route.render) {
        //     let result = this.props.route.render({
        //         match: (this.props as any).match,
        //         location: (this.props as any).location,
        //         history: (this.props as any).history
        //     });
        //     if (result && (result as PromiseLike<React.ReactNode>).then) {
        //         //is Promise
        //         (result as PromiseLike<React.ReactNode>).then(v => {
        //             this.setState({
        //                 node: v
        //             })
        //         })
        //     }
        //     else {
        //         //not Promise
        //         this.setState({
        //             node: result as React.ReactNode
        //         })
        //     }
        // }
        if (this.props.route.component) {
            if (typeof this.props.route.component == 'function') {
                //function
                var result = this.props.route.component();
                if (result.then) {
                    result.then(function (v) {
                        _this.setState({
                            componentClass: v.default
                        });
                    });
                }
                else {
                    //pure component function
                    this.setState({
                        componentClass: this.props.route.component
                    });
                }
            }
            else {
                //not function
                this.setState({
                    componentClass: this.props.route.component
                });
            }
        }
    };
    FullTsRouteRender.prototype.render = function () {
        var output = null;
        if (this.state.componentClass) {
            //component
            var Comp = this.state.componentClass;
            output = React.createElement(Comp, __assign({}, this.props.routeProps), this.props.children);
        }
        if (this.props.route.layout) {
            //Layout
            return React.createElement(FullTsRouteRender, { route: {
                    path: this.props.route.path,
                    component: this.props.route.layout
                }, routeProps: this.props.routeProps }, output);
        }
        else {
            return output;
        }
    };
    //<Switch></Switch>的BUG 如果不指定这个则会全部变成exact false
    FullTsRouteRender.defaultProps = {
        exact: true
    };
    return FullTsRouteRender;
}(React.Component));
export default FullTsRouteRender;
